@@ -15,7 +15,7 @@ memoize('compile_marc_path');
 memoize('parse_marc_spec');
 memoize('_get_index_range');
 
-our $VERSION = '1.31';
+our $VERSION = '1.33';
 
 sub marc_map {
     my $self = $_[0];
@@ -1056,7 +1056,7 @@ sub compile_marc_path {
     );
 
     my $MARC_PATH_REGEX
-        = qr/(\S{1,3})(\[([^,])?,?([^,])?\])?([\$_a-z0-9^-]+)?(\/([0-9]+)(-([0-9]+))?)?/;
+        = qr/(\S{1,3})(\[([^,])?,?([^,])?\])?([\$_a-zA-Z0-9^-]+)?(\/([0-9]+)(-([0-9]+))?)?/;
     if ( $marc_path =~ $MARC_PATH_REGEX ) {
         $field    = $1;
         $ind1     = $3;
